@@ -5,6 +5,7 @@ from monitors.page.cutter import VideoCutter
 from monitors.page.classifier import SVMClassifier
 from monitors.page.reporter import Reporter
 from monitors.page.video import VideoObject
+from loguru import logger
 
 
 def predict(video_path, report_path):
@@ -14,7 +15,7 @@ def predict(video_path, report_path):
     :param report_path:'index.html'
     :return:
     """
-
+    logger.info('------------ Start analyzing video！------------- ')
     video = VideoObject(video_path)
     video.load_frames()
 
