@@ -17,13 +17,13 @@ def get_process_id(process_name):
         pids = psutil.pids()
         for pid in pids:
             p = psutil.Process(pid)
-            if p.name() == process_name:
+            if p.name().lower() == process_name.lower():
                 app_pid.append(pid)
 
         app_parent_pid = []
         for app in app_pid:
             p = psutil.Process(app)
-            if p.parent().name() == process_parent_name:
+            if p.parent().name().lower() == process_parent_name.lower():
                 app_parent_pid.append(app)
         return app_parent_pid[0]
 
@@ -32,6 +32,7 @@ def get_process_id(process_name):
         pids = psutil.pids()
         for pid in pids:
             p = psutil.Process(pid)
-            if p.name() == process_name:
+            name = p.name().lower()
+            if name == process_name.lower():
                 app_pid.append(pid)
         return app_pid[0]
